# HG changeset patch
# User Jim Blandy <jimb@redhat.com>
# Date 721873864 0
# Node ID fed9a9ee51562bb3e67f5de3ba35f54f5a501508
# Parent  260271f9cd239bd5c2d8c9a1397fdb710530548b
	* s/sol2.h (LD_SWITCH_SYSTEM): Add -R option.

diff -r 260271f9cd23 -r fed9a9ee5156 src/s/sol2.h
--- a/src/s/sol2.h	Mon Nov 16 00:30:10 1992 +0000
+++ b/src/s/sol2.h	Mon Nov 16 00:31:04 1992 +0000
@@ -2,8 +2,9 @@
 
 #define POSIX
 
-/* Here is how to find X Windows.  */
-#define LD_SWITCH_SYSTEM -L/usr/openwin/lib
+/* Here is how to find X Windows.  The -L option tells the linker where
+   to find the libraries at link time, the -R option at run time.  */
+#define LD_SWITCH_SYSTEM -L/usr/openwin/lib -R/usr/openwin/lib
 #define C_SWITCH_X_SYSTEM -I/usr/openwin/include
 
 /* Compile in non-ansi fashion to work around bugs in system header files.  */